/******************************************************************************
 * test_analysis_x.cpp                                                        *
 *                                                                            *
 * Top Level file in analysis package                                         *
 * Drives the package                                                         *
 *****************************************************************************/
#define Global_cxx
#include "single_top_analysis/AnalysisMain.hpp"
#include <iostream>
#include <string>

// Include histogramming classes
#include "single_top_analysis/EventWeight.hpp"
#include "single_top_analysis/CutNJets.hpp"
#include "single_top_analysis/HistogrammingNJets.hpp"

// Include cuts classes
#include "single_top_analysis/CutBasic.hpp"

using std::cout;
using std::endl;

/******************************************************************************
 * int main(int argc, char **argv)                                            *
 *                                                                            *
 * Main Routine                                                               *
 *                                                                            *
 * Input:  Command line arguements                                            *
 * Output: Returns 0 of successful                                            *
 ******************************************************************************/
// Only declare main if not in CINT (not interactive?)
#ifndef __CINT__
int main(int argc, char **argv) 
#endif
{
  cout << "<driver> Starting parton_analysis" << endl;

  /////////////////////////////////////////////////////////////////////////////////
  // Decleartions and Instantiations
  /////////////////////////////////////////////////////////////////////////////////
  // Instantiate the analysis class
  AnalysisMain mystudy;

  // Delcare and Instantiate chains for the rootuples
  TChain *chainCollection = new TChain("CollectionTree");
  TChain *chainEVO        = new TChain("EV0");
  TChain *chainTruth      = new TChain("Truth0");
  
  /////////////////////////////////////////////////////////////////////////////////
  // Parse the Command Line
  /////////////////////////////////////////////////////////////////////////////////
  Int_t parseReturnValue = mystudy.ParseCmdLine(argc,argv,chainCollection,chainEVO,chainTruth);
  if(parseReturnValue != 0) return parseReturnValue;

  // Check command line for Fast Running
  // In Fast Running only a few cuts are made and histograms filled
  Bool_t doFast = kFALSE;
  for (int i = 1; i < argc; ++i) {
    //cout<<"Command line parameter "<<i<<" is "<<argv[i]<<endl;
    if (!strcmp(argv[i], "-fast")) {
      doFast = kTRUE;
      cout << "Driver: Fast running " << endl;
    }//if fast
  } // for
  

  /////////////////////////////////////////////////////////////////////////////////
  // Define a Particle class to be the same as the AnalysisMain class
  /////////////////////////////////////////////////////////////////////////////////
  Particles *particlesObj = &mystudy;
  
  /////////////////////////////////////////////////////////////////////////////////
  // Add Cuts and Histograms applicable to Fast and Full Analyses
  /////////////////////////////////////////////////////////////////////////////////
  // First always add the EventWeight
  mystudy.AddCut(new EventWeight(particlesObj));
  // Cut: Number of Jets
  mystudy.AddCut(new CutNJets(particlesObj));
  // Histograms: Number of Jets
  mystudy.AddCut(new HistogrammingNJets(particlesObj));
  
  /////////////////////////////////////////////////////////////////////////////////
  // Add Cuts and Histograms for Full Analysis
  /////////////////////////////////////////////////////////////////////////////////
  if(!doFast) {
    // Cut: D0-style preselection 
    //                                 Electron pt  eta; met; | Jet pt, eta, nmin, nmax; | Leading jet   pt  eta
    mystudy.AddCut(new CutBasic(particlesObj, 15.0, 2.0, 15.0,    15.0, 3.5,    2,    4,               25.0, 2.5));
    // Histograms: Number of Jets 
    mystudy.AddCut(new HistogrammingNJets(particlesObj));
  } // if(!doFast)
  
  cout << "<driver> Starting Loop over events in chain" << endl << endl;
    
  // Loop over events in chain
  mystudy.Loop();
  cout << "<driver> Finished Loop over events in chain" << endl;

  // Write output to files
  cout << "<driver> " << "Writing histograms to file: " << mystudy.GetHistogramFileName() << endl;
  mystudy.WriteHistogramFile();
  mystudy.CloseHistogramFile();
  
  // Delete chains and set pointers to NULL
  cout << "<driver> Deleting chains" << endl;

  if(chainTruth)      delete chainTruth;
  if(chainEVO)        delete chainEVO;
  if(chainCollection) delete chainCollection;

  chainTruth      = NULL;
  chainEVO        = NULL;
  chainCollection = NULL;
  
  cout << "<driver> Sucessful Completion." << endl;
  return 0;
}
