/******************************************************************************
 * CutNJets.hpp                                                               *
 *                                                                            *
 * Cuts on number of jets in an event                                         *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    CutNJets()                        -- Parameterized Constructor          *
 *    ~CutNJets()                       -- Destructor                         *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Apply cuts and fill histograms     *
 *    GetCutName()                      -- Returns "CutNJets"                 *
 *                                                                            *
 * Private Data Members of AnalysisMain class                                 *
 *    myTH1F* _hNJetsBefore              -- Hist of Num of jets before cuts   *
 *    myTH1F* _hNJetsAfter               -- Hist of Num of jets before cuts   *
 *                                                                            *
 * History                                                                    *
 *       7 Nov 2006 - Created by R. Schwienhorst for ATLAS                    *
 *      10 Nov 2006 - Modified by P. Ryan - cleanup and reorganized           *
 *****************************************************************************/

#include "single_top_analysis/CutNJets.hpp"
#include<iostream>

using namespace std;


/******************************************************************************
 * CutNJets::CutNJets(Particles *obj)                                         *
 *                                                                            *
 * Parameterized Constructor                                                  *
 *                                                                            *
 * Input:  Particle class                                                     *
 * Output: None                                                               *
 ******************************************************************************/
CutNJets::CutNJets(Particles *ParticlesObj)
{
  SetParticleObj(ParticlesObj);
} // CutNJets


/******************************************************************************
 * CutNJets::~CutNJets()                                                      *
 *                                                                            *
 * Destructor                                                                 *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
CutNJets::~CutNJets()
{
  
}//~CutNJets

/******************************************************************************
 * void CutNJets::BookHistogram()                                             *
 *                                                                            *
 * Book Histograms                                                            *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
void CutNJets::BookHistogram(){
  
  // Histogram of events before cut on number of jets
  _hNJetsBefore =  DeclareTH1F("NJetsBefore","Number of Jets before the cut",10, 0.0, 10.0);
  _hNJetsBefore -> SetXAxisTitle("N_{Jets}");
  _hNJetsBefore -> SetYAxisTitle("Events");

  // Histogram of events after cut on number of jets
  _hNJetsAfter =  DeclareTH1F("NJetsAfter","Number of Jets after the cut",10, 0.0, 10.0);
  _hNJetsAfter -> SetXAxisTitle("N_{Jets}");
  _hNJetsAfter -> SetXAxisTitle("Events");
  
  // Get configuration
  Particles *ParticlesObj = GetParticleObj();
  TEnv *config = ParticlesObj -> GetConfig();

  // Use configuration to set min and max number of jets to cut on
  _nJetsMin = config -> GetValue("Cut.Jet.Njets.Min", 0);
  _nJetsMax = config -> GetValue("Cut.Jet.Njets.Max", -1);
  
  
}//BookHistograms()

/******************************************************************************
 * Bool_t CutNJets::Apply()                                                   *
 *                                                                            *
 * Apply cuts and fill histograms                                             *
 *                                                                            *
 * Input:  None                                                               *
 * Output: kTrue if successful                                                *
 ******************************************************************************/
Bool_t CutNJets::Apply()
{
  //cout<<"Begin of CutNJets::Apply()"<<endl;

  // Get Event Tree
  Particles *ParticlesObj = GetParticleObj();
  EventTree *evTree = ParticlesObj -> GetEventTree();

  // Fill the histogram before the cut
  _hNJetsBefore -> Fill(evTree -> PJet_N);

  // Flag to signify if event passes cut
  Bool_t eventPass = kTRUE;

  // Cut on Min number of jets
  if(evTree -> PJet_N < _nJetsMin) eventPass = kFALSE;

  // Cut on Max number of jets
  // Negative cut value for Max means that there is no Max cut
  if( (_nJetsMax >= 0) && (evTree -> PJet_N > _nJetsMax) ) eventPass = kFALSE;

  // Fill the histogram after the cut
  if(eventPass) _hNJetsAfter -> Fill(evTree -> PJet_N);
  
  //cout<<"End of CutNJets::Apply()"<<endl;
  return eventPass;  
  
} //Apply












